=============
Miscellaneous
=============

.. currentmodule:: polars
.. autosummary::
   :toctree: api/

    LazyFrame.cache
    LazyFrame.collect
    LazyFrame.collect_async
    LazyFrame.collect_schema
    LazyFrame.lazy
    LazyFrame.map_batches
    LazyFrame.pipe
    LazyFrame.profile

Serialization
-------------

.. autosummary::
   :toctree: api/

    LazyFrame.deserialize
    LazyFrame.serialize
